@@ -1,19 +1,22 @@
 # -*- coding:utf-8 -*-
 from django.contrib import admin
-from coop.org.models import BaseEngagement,BaseOrganization,BaseRelation
-from coop.exchange.models import BaseExchange,BasePaymentModality,BaseTransaction
-from coop.person.models import BasePerson
+from coop.org.models import BaseEngagement, BaseRelation
+from coop.exchange.models import BaseExchange, BasePaymentModality, BaseTransaction
 from django.db import models
 from django import forms
 from django.conf import settings
 
-from django.contrib.admin.widgets import FilteredSelectMultiple
+# from django.contrib.admin.widgets import FilteredSelectMultiple
 from django.db.models.loading import get_model
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.contenttypes.generic import GenericTabularInline
-from coop.utils.autocomplete_admin import FkAutocompleteAdmin,InlineAutocompleteAdmin
+from coop.utils.autocomplete_admin import FkAutocompleteAdmin, InlineAutocompleteAdmin
 from django_extensions.admin import ForeignKeyAutocompleteAdmin
 
+from coop_local.models import Contact, Person
+from coop_geo.models import Location
+from django.contrib.contenttypes.models import ContentType
+from django.db.models import Q
 
 from django.contrib.admin.widgets import AdminURLFieldWidget
 from django.db.models import URLField
@@ -25,11 +28,11 @@ from sorl.thumbnail import default
 ADMIN_THUMBS_SIZE = '60x60'
 
 
-
 class SimpleLinkWidget(forms.Widget):
     def __init__(self, obj, attrs=None):
         self.object = obj
         super(SimpleLinkWidget, self).__init__(attrs)
+
     def render(self, name, value, attrs=None):
         if self.object.pk:
             return mark_safe(
@@ -50,60 +53,68 @@ class M2MLinkWidget(forms.Widget):
         self.object = obj
         self.fkey = fkey_name
         super(M2MLinkWidget, self).__init__(attrs)
+
     def render(self, name, value, attrs=None):
         if self.object.pk:
             return mark_safe(u'<a href="../../../%s/%s/%s/">%s</a>' % \
-                (   self.object._meta.app_label,
-                    getattr(self.object,self.fkey)._meta.object_name.lower(), 
-                    getattr(self.object,self.fkey).pk, 
-                    u' '.join((u'Fiche',unicode(self.fkey))) # TODO how to get the translated app name ?
+                (self.object._meta.app_label,
+                    getattr(self.object, self.fkey)._meta.object_name.lower(), 
+                    getattr(self.object, self.fkey).pk, 
+                    u' '.join((u'Fiche', unicode(self.fkey)))  # TODO how to get the translated app name ?
                     )
             )
         else:
             return mark_safe(u'')
 
+
 class ExchangeInlineLinkForm(forms.ModelForm):
     class Meta:
         model = BaseExchange
     lien = forms.CharField(label='lien', required=False)
+
     def __init__(self, *args, **kwargs):
         super(ExchangeInlineLinkForm, self).__init__(*args, **kwargs)
         self.fields['lien'].widget = SimpleLinkWidget(self.instance)        
 
+
 class ContactInlineLinkForm(forms.ModelForm):
     lien = forms.CharField(label='lien', required=False)
+
     def __init__(self, *args, **kwargs):
         super(ContactInlineLinkForm, self).__init__(*args, **kwargs)
-        self.fields['lien'].widget = M2MLinkWidget(self.instance,fkey_name='person')
+        self.fields['lien'].widget = M2MLinkWidget(self.instance, fkey_name='person')
+
 
 class OrgInlineLinkForm(forms.ModelForm):
     lien = forms.CharField(label='lien', required=False)
+
     def __init__(self, *args, **kwargs):
         super(OrgInlineLinkForm, self).__init__(*args, **kwargs)
-        self.fields['lien'].widget = M2MLinkWidget(self.instance,fkey_name='organization')
+        self.fields['lien'].widget = M2MLinkWidget(self.instance, fkey_name='organization')
 
 
 # ---------- if coop-geo is installed --------------
 
-if "coop_geo" in settings.INSTALLED_APPS :
-    from coop_geo.models import AreaLink,Located
+if "coop_geo" in settings.INSTALLED_APPS:
+    from coop_geo.models import AreaLink, Located
 
     class LocatedInlineLinkForm(forms.ModelForm):
         lien = forms.CharField(label='lien', required=False)
+
         def __init__(self, *args, **kwargs):
             super(LocatedInlineLinkForm, self).__init__(*args, **kwargs)
-            self.fields['lien'].widget = M2MLinkWidget(self.instance,fkey_name='location')
+            self.fields['lien'].widget = M2MLinkWidget(self.instance, fkey_name='location')
 
-    class LocatedInline(GenericTabularInline,InlineAutocompleteAdmin):
+    class LocatedInline(GenericTabularInline, InlineAutocompleteAdmin):
         form = LocatedInlineLinkForm
         model = Located
-        related_search_fields = {'location': ('label','adr1','adr2','zipcode','city'), }
-        extra=1
+        related_search_fields = {'location': ('label', 'adr1', 'adr2', 'zipcode', 'city'), }
+        extra = 1
 
-    class AreaInline(GenericTabularInline,InlineAutocompleteAdmin):
+    class AreaInline(GenericTabularInline, InlineAutocompleteAdmin):
         model = AreaLink
-        related_search_fields = {'location': ('label','reference'), }
-        extra=1
+        related_search_fields = {'location': ('label', 'reference'), }
+        extra = 1
 
 # ----------------------------------------------------
 
@@ -115,27 +126,31 @@ class URLFieldWidget(AdminURLFieldWidget):
                          u'open(document.getElementById(\'%s\')'
                          u'.value);return false;" /></a>' % (widget, attrs['id']))
 
+
 class BaseEngagementInline(InlineAutocompleteAdmin):
     form = ContactInlineLinkForm
     model = BaseEngagement
-    related_search_fields = {'person': ('last_name','first_name','email','structure','username'), }
-    extra=2
+    related_search_fields = {'person': ('last_name', 'first_name', 'email', 'structure', 'username'), }
+    extra = 2
+
 
 class BaseOrgInline(InlineAutocompleteAdmin):
     form = OrgInlineLinkForm
     model = BaseEngagement
-    related_search_fields = {'organization': ('title','subtitle','description'), }
-    extra=1
+    related_search_fields = {'organization': ('title', 'subtitle', 'description'), }
+    extra = 1
+
 
 class BasePaymentInline(admin.TabularInline):
     model = BasePaymentModality
-    extra=0
+    extra = 0
+
 
 class BaseExchangeInline(admin.StackedInline):
     #form = ExchangeInlineLinkForm #needed to include a link to the change_form / only because nested inlines are not possible
     model = BaseExchange
-    fieldsets = ((None, {'fields' : ('title',
-                                    ('etype','permanent','expiration'),
+    fieldsets = ((None, {'fields': ('title',
+                                    ('etype', 'permanent', 'expiration'),
                                     'description',
                                     #'lien'
                                     )}),)
@@ -146,8 +161,8 @@ class BaseExchangeInline(admin.StackedInline):
 class BaseTransactionInline(admin.StackedInline):
     model = BaseTransaction
     fk_name = 'destination_org'
-    fieldsets = ((None, {'fields': ('title','origin','description')}),)
-    related_search_fields = {'origin': ('title','description','organization__title'), }
+    fieldsets = ((None, {'fields': ('title', 'origin', 'description')}),)
+    related_search_fields = {'origin': ('title', 'description', 'organization__title'), }
     extra = 1
 
 
@@ -155,19 +170,39 @@ class BaseRelationInline(InlineAutocompleteAdmin):
     model = BaseRelation
     fk_name = 'source'
     readonly_fields = ('created',)
-    fields = ('reltype','target','confirmed','created')
-    related_search_fields = {'target': ('title','subtitle','description'), }
-    extra=1
+    fields = ('reltype', 'target', 'confirmed', 'created')
+    related_search_fields = {'target': ('title', 'subtitle', 'description'), }
+    extra = 1
        
 
- 
 from chosen import forms as chosenforms
 from chosen import widgets as chosenwidgets
    
-class BaseOrganizationAdminForm(forms.ModelForm): 
+
+class BaseOrganizationAdminForm(forms.ModelForm):
     class Meta:
         widgets = {'category': chosenwidgets.ChosenSelectMultiple()}
 
+    def __init__(self, *args, **kwargs):
+        super(BaseOrganizationAdminForm, self).__init__(*args, **kwargs)
+        engagements = self.instance.engagement_set.all()
+        members_id = engagements.values_list('person_id', flat=True)
+        print members_id
+        org_contacts = Contact.objects.filter(
+            Q(content_type=ContentType.objects.get(model='organization'), object_id=self.instance.id)
+          | Q(content_type=ContentType.objects.get(model='person'), object_id__in=members_id)
+            )
+        self.fields['pref_email'].queryset = org_contacts.filter(category=8)
+        self.fields['pref_phone'].queryset = org_contacts.filter(category=1)
+        
+        member_locations_id = [m.location.id for m in 
+            Person.objects.filter(id__in=members_id).exclude(location=None)]  # limit SQL to location field
+
+        self.fields['pref_address'].queryset = Location.objects.filter(
+            Q(id__in=self.instance.located.all().values_list('location_id', flat=True))
+          | Q(id__in=member_locations_id)
+            )
+
 
 class BaseMemberAdminForm(forms.ModelForm):
     # category = chosenforms.ChosenModelMultipleChoiceField(
@@ -178,28 +213,29 @@ class BaseMemberAdminForm(forms.ModelForm):
         widgets = {'category': chosenwidgets.ChosenSelectMultiple()}
 
 
-class BaseExchangeAdmin(ForeignKeyAutocompleteAdmin): #AdminImageMixin, 
+class BaseExchangeAdmin(ForeignKeyAutocompleteAdmin):  # AdminImageMixin, 
     fieldsets = ((None, {
-            'fields' : (('etype','permanent','expiration',),'title','description',
+            'fields': (('etype', 'permanent', 'expiration', ), 'title', 'description',
                        'organization'
                        )
             }),)
-    related_search_fields = {'organization': ('title','subtitle','description'), }
+    related_search_fields = {'organization': ('title', 'subtitle', 'description'), }
 
 
 def create_action(category):
     def add_cat(modeladmin, request, queryset):
-        for obj in queryset:obj.category.add(category)
+        for obj in queryset:
+            obj.category.add(category)
     name = "cat_%s" % (category.slug,)
     return (name, (add_cat, name, _(u'Add to the "%s" category') % (category,)))
 
 
 class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
     form = BaseOrganizationAdminForm
-    list_display = ('logo_thumb','title','active','has_description',)
-    list_display_links =('title',)
-    search_fields = ['title','subtitle','description']
-    list_filter = ('active','category')
+    list_display = ('logo_thumb', 'title', 'active', 'has_description',)
+    list_display_links = ('title', )
+    search_fields = ['title', 'subtitle', 'description']
+    list_filter = ('active', 'category')
     actions_on_top = True
     actions_on_bottom = True
     save_on_top = True
@@ -211,7 +247,7 @@ class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
     formfield_overrides = {
         URLField: {'widget': URLFieldWidget},
     }
-    inlines = [ # overriden in coop_local
+    inlines = [  # overriden in coop_local
                         BaseEngagementInline,
                         # LocatedInline,
                         # AreaInline,
@@ -220,8 +256,12 @@ class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
                         ]
     fieldsets = (
         (None, {
-            'fields' : ('logo','title','subtitle',('birth','active',),
-                        ('email','web'),'description','category',
+            'fields': ('logo', 'title', 'subtitle', ('birth', 'active',),
+                        'web',
+                        'pref_email',
+                        'pref_phone',
+                        'pref_address',
+                        'description', 'category',
                         )
             }),
         ('Notes', {
@@ -229,9 +269,10 @@ class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
             'fields': ('notes',)
         })
     )
+
     def get_actions(self, request):
-        myactions = dict(create_action(s) for s in get_model('coop_local','OrganizationCategory').objects.all())
-        return dict(myactions, **super(BaseOrganizationAdmin, self).get_actions(request))#merging two dicts
+        myactions = dict(create_action(s) for s in get_model('coop_local', 'OrganizationCategory').objects.all())
+        return dict(myactions, **super(BaseOrganizationAdmin, self).get_actions(request))  # merging two dicts
         #list_display = ['my_image_thumb', 'my_other_field1', 'my_other_field2', ] ???
 
     def logo_thumb(self, obj):
@@ -242,12 +283,14 @@ class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
             return _(u"No Image") 
     logo_thumb.short_description = _(u"logo")
     logo_thumb.allow_tags = True
+
     class Media:
         js = ('/static/js/admin_customize.js',)
 
 
 from django_extensions.admin import ForeignKeyAutocompleteAdmin
         
+
 class BasePersonAdmin(ForeignKeyAutocompleteAdmin):
     # model is not given because the coop_local "true" model will override this
     form = BaseMemberAdminForm
