@@ -8,6 +8,9 @@ from django.template.defaultfilters import slugify
 from django.contrib.contenttypes import generic
 from django.contrib.sites.models import Site
 from django.conf import settings
+from django.contrib.contenttypes.models import ContentType
+from django.contrib.contenttypes import generic
+from coop.models import URIModel
 
 if "coop_geo" in settings.INSTALLED_APPS:
     from coop_geo.models import Location
@@ -28,7 +31,7 @@ class BasePersonCategory(models.Model):
 from coop.org.models import DISPLAY
 
 
-class BasePerson(models.Model):
+class BasePerson(URIModel):
     user = models.OneToOneField(User, blank=True, null=True, unique=True, verbose_name=_(u'django user'), editable=False)
     username = models.CharField(blank=True, max_length=100, unique=True)    
     #pour D2RQ et poura voir des URI clean meme pour des non-users
@@ -46,6 +49,8 @@ class BasePerson(models.Model):
     notes = models.TextField(_(u'notes'), blank=True, null=True)
     structure = models.CharField(blank=True, max_length=100)
 
+    subs = generic.GenericRelation('coop_local.Subscription')
+
     if "coop_geo" in settings.INSTALLED_APPS:
         location = models.ForeignKey(Location, null=True, blank=True, verbose_name=_(u'location'))
         location_display = models.PositiveSmallIntegerField(_(u'Display'), choices=DISPLAY.CHOICES, default=DISPLAY.USERS)
@@ -79,9 +84,11 @@ class BasePerson(models.Model):
             eng.append({'initiative': e.initiative, 'role': e.role})
         return eng
 
-    def init_uri(self):
-        return 'http://' + Site.objects.get_current().domain + '/webid/' + self.username + '/'
-    
+    @property
+    def uri_id(self):
+        return self.username
+    uri_fragment = 'person'
+
     def save(self, *args, **kwargs):
         if self.email != '':
             import hashlib
@@ -103,8 +110,5 @@ class BasePerson(models.Model):
                     chg = True
             if(chg):
                 self.user.save()
-        # create / update URI           
-        if self.uri != self.init_uri():
-            self.uri = self.init_uri()
         super(BasePerson, self).save(*args, **kwargs)    
 
